#!/bin/bash
source `dirname $0`/scripts/shared/util.sh

function usage () {
  code=$1
  printf "Usage: docker-build [OPTIONS] TAG\n"
  printf " The dockerfile should be named 'Dockerfile-TAG'\n"
  printf "Options:\n"
  printf "    -h       Show this message\n"
  printf "    -p       Push completed Dockerfile to NERSC\n"
  exit $code
}

tag=""
opt_push="no"
while [ $# -gt 0 ]; do
  case "$1" in
    -h) usage; exit 0;;
    -p) opt_push="yes";;
    -*) printf "Unrecognized option: $1\n"; usage 2 ;;
    *) tag="$1" ;;
  esac
  shift
done

dockerfile="Dockerfile-${tag}"
if [ ! -e $dockerfile ]; then
  printf "Dockerfile '$dockerfile' not found\n"
  usage
  exit 2
fi

LOG=/tmp/docker-${tag}-build.log
cprintln b "Building ${dockerfile}. Logs in $LOG"
docker build  -f $dockerfile -t $tag . 2>&1 | tee $LOG | \
 grep -E '^Step| --->|The command.*non-zero code'

buildok=0
rcode=`tail -1 $LOG  | \
       grep -E "non-zero code: [0-9]+" -o | \
       cut -f2 -d':' | tr -d ' '`
if [ "$rcode" ]; then
  cprintln r "Build failed ($rcode)."
  cprintln a "  Log is in $LOG"
else
  cprintln g "Build succeeded."
  buildok=1
fi

if [ $buildok -eq 1 -a $opt_push = yes ]; then
  cprintln b "$squiggly"
  cprintln g "Uploading to NERSC Docker registry"
  imageid=`grep  '^Successfully built [a-z0-9]*$' $LOG  | cut -f3 -d' '`
  if [ "x$imageid" = x ]; then
    cprintln r "Abort. Cannot get image ID from $LOG"
  else
    cprintln a "  tagging image $imageid as $tag"
    docker tag $imageid registry.services.nersc.gov/dang/${tag}:latest
    cprintln a "  pushing image ${tag}:latest"
    docker push registry.services.nersc.gov/dang/${tag}:latest
  fi
fi
