##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
import alamopy
import argparse
import random
import numpy as np
from idaes.dmf import surrmod
from idaes.dmf.dmf import DMF
from idaes.dmf.experiment import Experiment

x1range = (-2, 2)
x2range = (-1, 1)


def create_data(ndata=10, nvaldata=1000, rng=0.001):
    random.seed(200)
    xdatanp = np.zeros([ndata, 2])
    zdatanp = np.zeros([ndata, 1])
    # Construct input
    for i in range(ndata):
        xdatanp[i][0] = random.uniform(*x1range)
        xdatanp[i][1] = random.uniform(*x2range)
        zdatanp[i] = (4 * xdatanp[i][0] - 3 * xdatanp[i][1] + 2 +
                      random.uniform(-rng, rng))

    xvaldatanp = np.zeros([nvaldata, 2])
    zvaldatanp = np.zeros([nvaldata, 1])
    for i in range(nvaldata):
        xvaldatanp[i][0] = random.uniform(*x1range)
        xvaldatanp[i][1] = random.uniform(*x2range)
        zvaldatanp[i] = (4 * xvaldatanp[i][0] - 3 * xvaldatanp[i][1] + 2 +
                         random.uniform(-rng, rng))

    return xdatanp, zdatanp, xvaldatanp, zvaldatanp


def doalamo(x, z, xval, zval):
    xmin = (x1range[0], x2range[0])
    xmax = (x1range[1], x2range[1])
    res = alamopy.doalamo(x, z, xval=xval, zval=zval,
                          xlabels=('x1', 'x2'), xmin=xmin, xmax=xmax,
                          monomialpower=(1,), showalm=False,
                          simulator='linsim.py', sampler=1, maxiter=5,
                          expandoutput=True)

    res = alamopy.almconfidence(res)
    return res


def do_surrogate_model(x, z, xval, zval, **dmf_kw):
    dmf = DMF(**dmf_kw)
    exp = Experiment(dmf, desc='Surrogate modeling example with simple linear '
                               'model.')
    m = surrmod.SurrogateModel(exp, monomialpower=(1,),
                               showalm=False, simulator='linsim.py', sampler=1,
                               maxiter=5, expandoutput=True)
    m.set_input_data_np(x, z, xlabels=('x1', 'x2'))
    m.set_validation_data_np(xval, zval)
    res = m.run()
    return res


if __name__ == '__main__':
    p = argparse.ArgumentParser()
    p.add_argument('ws', help='Workspace')
    args = p.parse_args()
    res = do_surrogate_model(*create_data(), path=args.ws)
    print(res)
