##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
from __future__ import division
from __future__ import print_function
__author__ = "John Eslick"
__version__ = "1.0.0"

from pyomo.environ import *
from idaes.core.unit_model import UnitModel

class OnePhaseInlet(UnitModel):
    def __init__(self, comp):
        UnitModel.__init__(self)
        self.comp = comp
        
    def __call__(self, blk, index=0):
        self.pyomo_block = blk
        blk.T = Var(domain=Reals, bounds=(200,500), 
                    initialize=300, doc="Temperature (K)")
        blk.P = Var(domain=Reals, bounds=(50000,1e6), 
                    initialize=105000, doc="Pressure (Pa)")
        blk.y = Var(self.comp, domain=Reals, bounds=(0,1),
                    initialize=0.5, doc="Mole Fraction (mol/mol total)")
        blk.F = Var(domain=Reals, bounds=(0,1000),
                    initialize=1, doc="Flowrate (mol/s)")
        blk.out = self.one_phase_fluid_port(
            blk.F, blk.T, blk.P, blk.y)
        
        self.out = blk.out
            
    def fix(self):
        self.pyomo_block.T.fix()
        self.pyomo_block.P.fix()
        self.pyomo_block.y.fix()
        self.pyomo_block.F.fix()
