##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
from idaes.dmf import resource

# Create an empty resource
rsrc = resource.Resource(type='plot')

# Populate the resource. All the attributes are optional.
# This is set automatically to current time
rsrc.created = '2017-10-31'
# This is set automatically to current time
rsrc.modified = '2017-11-23'
# Description of the resource
rsrc.desc = 'Plots of the Iris dataset'
# Version of the resource
rsrc.version = resource.Version(revision='1.0.3-a7',
                                name='november-release')
# Name and contact email of creator of the resource
rsrc.creator = resource.Contact(name='Dan Gunter',
                                email='dang@science-lab.gov')
# Name and contact email of other people involved
rsrc.collaborators = [resource.Contact(name='John Eslick',
                      email='john@science-lab.gov'),
                     resource.Contact(name='David Miller',
                                      email='david@science-lab.gov')]
# Provenance: sources, such as publications -- but
# really anything is allowed -- for the resource.
rsrc.sources = [resource.Source(
             source='R. A. Fisher. "The use of multiple measurements '
                    'in taxonomic problems". '
                    'Annals of Eugenics. 7 (2): 179-188.',
             doi='10.1111/j.1469-1809.1936.tb02137.x', date='1936'),
           resource.Source(source='Edgar Anderson. '
                                  '"The species problem in Iris". '
                                  'Annals of the Missouri Botanical Garden. '
                                  '23 (3): 457-509. '
                                  'JSTOR 2394164',
                           date='1936')]
# Associated code files, including Jupyter notebooks.
# If these codes are worth making into their own Resources,
# you should not put them here, but instead link to them
# through the `relations` attribute.
rsrc.codes = [resource.Code(type='notebook',
                        desc='Python plotting code',
                       name='plot_iris_dataset.ipynb',
                       language='Python',
                       location='http://scikit-learn.org/stable/_downloads/'
                                'plot_iris_dataset.ipynb')]
# Associated data files. Same comment as for `codes` re: linking.
rsrc.datafiles = [resource.FilePath(path='iris-data.csv',
                                    desc='Iris data')]
# Short names that make it easier to find this resource.
rsrc.aliases = ['iris', 'iris-plots']
# Tags that make it easier to find this resource later.
rsrc.tags = ['iris', 'anderson', 'fisher']
# Arbitrary additional data to add into the resource.
# Note that larger data units should be made into files and
# added into the `datafiles` attributes.
rsrc.data = {
    'features': ['sepal length (cm)', 'sepal width (cm)',
                  'petal length (cm)', 'petal width (cm)'],
    # the data is already defined in the datafile,
    # but we could also put it here, inline
    'array': [[5.1, 3.5, 1.4, 0.2], [4.9, 3.0, 1.4, 0.2],
              [4.7, 3.2, 1.3, 0.2], [4.6, 3.1, 1.5, 0.2],
              [5.0, 3.6, 1.4, 0.2], [5.4, 3.9, 1.7, 0.4],
              # ... you get the idea..
             ]
}
