##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
from idaes.vis.plot import Plot
from idaes.vis.vis_exceptions import *
from pandas import DataFrame
import numpy as np
"""
Sanity tests for the visualization module.
"""
import unittest
import warnings

class TestVis(unittest.TestCase):

    def setUp(self):

        # Values in the following data-frame are based on MEA values from the MEA notebook.
        self.plot_dict = DataFrame(data={'z':sorted(np.random.uniform(low=0, high=20, size=(100,))),
             'y1':sorted(np.random.uniform(low=500, high=11700, size=(100,))),
             'y2':sorted(np.random.uniform(low=175, high=1200, size=(100,)))})

    def test_plot_proper_warning_message(self):
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")
            plot_object = Plot.profile(self.plot_dict,
                             x = 'z',
                             y = ['y1','y2'],
                             title = 'Absorber CO2 Levels',
                             xlab = 'Axial distance from top (m)',
                             ylab = 'Partial Pressure CO2 (Pa)',
                             legend = ['Bulk vapor','Equilibrium'])
            # Verify some things
            assert (len(w) == 1)
            assert ("visualization library is still in active development" in str(w[-1].message))        

    
    def test_plot_object_return(self):
        """Test proper profile plots"""        
        with warnings.catch_warnings():
            warnings.simplefilter("ignore")
            plot_object = Plot.profile(self.plot_dict,
                                     x = 'z',
                                     y = ['y1','y2'],
                                     title = 'Absorber CO2 Levels',
                                     xlab = 'Axial distance from top (m)',
                                     ylab = 'Partial Pressure CO2 (Pa)',
                                     legend = ['Bulk vapor','Equilibrium'])
            assert(isinstance(plot_object,Plot))

    def test_plot_fail_on_invalid_data_frame(self):
        """Test failure on a bad data frame"""
        try:
            plot_object = Plot.profile(self.plot_dict,
                                     x = 'z1',
                                     y = ['y2','y3'],
                                     title = 'Absorber CO2 Levels',
                                     xlab = 'Axial distance from top (m)',
                                     ylab = 'Partial Pressure CO2 (Pa)',
                                     legend = ['Bulk vapor','Equilibrium'])
        except Exception as e:
            print(e)
            assert(isinstance(e,BadDataFrameException))


    def test_plot_fail_on_bad_legend(self):
        """Test failure on bad legend"""
        try:
            plot_object = Plot.profile(self.plot_dict,
                             x = 'z',
                             y = ['y1','y2'],
                             title = 'Absorber CO2 Levels',
                             xlab = 'Axial distance from top (m)',
                             ylab = 'Partial Pressure CO2 (Pa)',
                             legend = [])
        except Exception as e:
            print(e)
            assert(isinstance(e,MissingVariablesException))
