##############################################################################
# Institute for the Design of Advanced Energy Systems Process Systems
# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018, by the
# software owners: The Regents of the University of California, through
# Lawrence Berkeley National Laboratory,  National Technology & Engineering
# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
# University Research Corporation, et al. All rights reserved.
# 
# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
# license information, respectively. Both files are also available online
# at the URL "https://github.com/IDAES/idaes".
##############################################################################
"""
Write (some sort of) test of the documentation build.
Really this is a test of the base install script.
"""
import os
import shutil
from subprocess import Popen
import tempfile
#
import pytest

jenkins = os.environ.get('JENKINS_URL', None) is not None


@pytest.fixture
def build_script():
    script = doc_script()
    tmpf = tempfile.NamedTemporaryFile(mode='wb', delete=False)
    print('Writing script to file: {}'.format(tmpf.name))
    tmpf.write(script.encode())
    tmpf.close()
    yield tmpf.name
    print('Cleanup')
    os.unlink(tmpf.name)


@pytest.fixture
def bad_build_script():
    script = doc_script(bad=True)
    tmpf = tempfile.NamedTemporaryFile(mode='wb', delete=False)
    print('Writing script to file: {}'.format(tmpf.name))
    tmpf.write(script.encode())
    tmpf.close()
    yield tmpf.name
    print('Cleanup')
    os.unlink(tmpf.name)


@pytest.fixture
def output_file():
    f = tempfile.NamedTemporaryFile(mode='w', prefix='idaes-', suffix='.out')
    return f


@pytest.fixture
def error_file():
    f = tempfile.NamedTemporaryFile(mode='w', prefix='idaes-', suffix='.err')
    return f


def doc_script(bad=False):
    """Create a documentation script.
    """
    # The script. It is important that the last
    # command return the exit code. Don't add extra
    # print statements or something.
    if bad:
        commands = ['this should not work']
    else:
        if jenkins:
            commands = ['cd doc', 'make dep html']
        else:
            commands = ['printf "nothing to do\n"']
    return '\n'.join(commands)

# Tests


def test_doc_build(build_script, output_file, error_file):
    curdir = os.getcwd()
    # Go up until you hit the root
    while 1:
        if 'setup.py' in os.listdir('.'):
            break
        os.chdir('..')
    print('In root directory "{}"'.format(os.getcwd()))

    # Run
    print('Running script "{}"'.format(build_script))
    proc = Popen(['/bin/sh', build_script], stdout=output_file,
                 stderr=error_file)
    proc.wait()
    if proc.returncode != 0:
        logfile = os.path.join(curdir, 'doc_build.{}')
        shutil.copy(output_file.name, logfile.format('out'))
        shutil.copy(error_file.name, logfile.format('err'))
        assert False, 'Script failed. Output in {}. Errors in {}.'.format(
            logfile.format('out'), logfile.format('err'))



def test_doc_build_fail(bad_build_script, output_file, error_file):
    proc = Popen(['/bin/sh', bad_build_script], stdout=output_file,
                 stderr=error_file)
    proc.wait()
    assert proc.returncode != 0
