#!/usr/bin/env python
"""
Print versions of packages, from requirements, based on what
is installed in the current environment.
"""
import subprocess
import re
import sys


def not_found(pkg):
    sys.stderr.write('warning: {} not installed\n'.format(pkg))


def main():
    req = open('requirements.txt').readlines()
    p = subprocess.Popen(['pip', 'freeze'], stdout=subprocess.PIPE)
    frozen = p.stdout.readlines()
    pkg_ver = {}
    for spec in frozen:
        if 'github.com' in spec: continue
        pkg, ver = spec.strip().split('==')
        canon_pkg = pkg.lower()
        pkg_ver[canon_pkg] = ver
    for line in req:
        if re.match('[a-zA-Z_-]+[><=]=.*', line):
            continue
        pkg = line.strip().lower()
        if pkg in pkg_ver:
            print('{}=={}'.format(pkg, pkg_ver[pkg]))
        else:
            not_found(pkg)
            print(pkg)


if __name__ == '__main__':
    main()
